/**
  (c) Copyright CERN 2005. All rights not expressly granted are reserved.
icecontrols.support@cern.ch

  SPDX-License-Identifier: LGPL-3.0-only
**/

/** @name LIBRARY: unImportValidationDeprecated.ctl

Creation date: 2018-06-22

Purpose:
This library contains deprecated functions from unImportValidation libraries, 
that may be eventually removed from component distribution. 

*/


//------------------------------------------------------------------------------------------------------------------------

// unImportValidation_exportSilent
/**
Purpose: export in silent mode

Parameters:
		@param bNoTreeDef, bool, input, true=do not export the tree definition/false=export the tree definition
		@param sNodeNameToExport, string , input, the node name to export
		@param sDpNodeNameToExport, string , input, the dp node name to export
		@param bKeepSystemName, bool , input, true=keep the system name for the plot DPE/false=replace the system name by #local:
		@param sSystemName, string , input, the system name to replace and the system name to export sNodeNameToExport
		@param dsData, dyn_string , output, the exported data, WARNING \t are included
		@param exInfo, dyn_string, output, for errors
		
Usage: External function

PVSS manager usage: Ctrl, NG, NV

Constraints:
	. PVSS version: 3.0 
	. operating system: NT and W2000, but tested only under W2000.
	. distributed system: yes.
  
  @deprecated 2018-06-22
*/

unImportValidation_exportSilent(bool bNoTreeDef, string sNodeNameToExport, string sDpNodeNameToExport, bool bKeepSystemName, 
																																string sSystemName, dyn_string &dsData, dyn_string &exInfo)
{
  FWDEPRECATED();
  
	string sNodeName=sNodeNameToExport;
	string sText, sParentNodeName;
	int iFileExists;
	int i, len;
	dyn_string dsTreeData;
	string sTreeDp=sDpNodeNameToExport;
	dyn_string dsExportTree_exportedDevice, dsExportTree_navigationDevice;
	bool bConnected, bRemote;
		
	dsExportTree_exportedDevice= makeDynString();
	dsExportTree_navigationDevice = makeDynString();
	//Get File to export choosed by user
	if(sSystemName == "")
		sSystemName = getSystemName();
		
	unDistributedControl_isRemote(bRemote, sSystemName);
	if(bRemote) 
		unDistributedControl_isConnected(bConnected, sSystemName);
	else
		bConnected = true;

	if(bConnected) {
		if(bNoTreeDef) {
			if(dpExists(sDpNodeNameToExport)) {
				if(dpTypeName(sDpNodeNameToExport) == "_FwTreeType")
					sTreeDp = "";
				else
					bNoTreeDef = false;
			}
			else
				fwException_raise(exInfo, "ERROR", "unImportValidation_exportSilent: dp not existing "+sDpNodeNameToExport, "");
		}			
		if(sNodeName != "") {
			unExportTree_exportTreeData(dsTreeData, sTreeDp, sNodeName, bKeepSystemName, sSystemName, dsExportTree_navigationDevice, dsExportTree_exportedDevice, exInfo);
			if(bNoTreeDef) {
				sParentNodeName = unImportValidation_getTagValue(dsTreeData, "<parentname>");
				i=dynContains(dsTreeData, "		<parentname>"+sParentNodeName+"</parentname>");
//DebugN("bef", dsTreeData);
				if(i>0) 
					dsTreeData[i] = "		<parentname></parentname>";
			}
//DebugN("after", dsTreeData, sParentNodeName, i);
			dsData = dsTreeData;
		}
		else
			fwException_raise(exInfo, "ERROR", "unImportValidation_exportSilent: empty node name", "");
	}
	else
		fwException_raise(exInfo, "ERROR", "unImportValidation_exportSilent: system not connected "+sSystemName, "");
}

//------------------------------------------------------------------------------------------------------------------------

// unImportValidation_exportImportSilent
/**
Purpose: export/check/import in silent mode with no tree definition and keep the system name

Parameters:
		@param sNodeNameToExport, string , input, the node name to export
		@param sNodeDpToExport, string , input, the dp node name to export
		@param sSystemName, string , input, the system name to replace and the system name to export sNodeNameToExport
		@param bImportInto, bool, input, true=import into sImportIntoNodeName/false=do not import into sImportIntoNodeName
		@param sImportIntoNodeName, string , input, the node name to import the data into
		@param exError, dyn_string, output, for errors
		@param exWarning, dyn_string, output, for warnings
		
Usage: External function

PVSS manager usage: Ctrl, NG, NV

Constraints:
	. PVSS version: 3.0 
	. operating system: NT and W2000, but tested only under W2000.
	. distributed system: yes.
  
  @deprecated 2018-06-22
*/

unImportValidation_exportImportSilent(string sNodeNameToExport, string sNodeDpToExport, string sSystemName, bool bImportInto, 
																										string sImportIntoNodeName, dyn_string &exError, dyn_string &exWarning)
{
  FWDEPRECATED();

	fwException_raise(exError, "ERROR", "unImportValidation_exportImportSilent: not implemented", "");
	return;
}

//------------------------------------------------------------------------------------------------------------------------

// unImportValidation_cleanTreeHeader
/**
Purpose:
remove the xml version and replace the tree tag definition

	@param dsFileContent: dyn_string, input/output: data

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. the JCOP hierarchy management
	. to be used with the unTreeWidget and 
	the Microsoft ProgressBar Control, version 6.0
	. PVSS version: 3.0 
	. operating system: NT and W2000, but tested only under W2000.
	. distributed system: yes.
  
  @deprecated 2018-06-22
*/

unImportValidation_cleanTreeHeader(dyn_string &dsFileContent)
{
  FWDEPRECATED();

  dynRemove(dsFileContent, 1); // remove the xml version
  dsFileContent[1] = "<tree>";
}

//------------------------------------------------------------------------------------------------------------------------
// unImportValidation_getTreeData
/**
Purpose:
get the configuration data of the tree

	@param dsFileContent: dyn_string, input: the content of the file to check
	@param dsData: dyn_string, output: the data of the tree are returned here
	@param iIndex: int, output: the index in the file after extracting the data

Usage: Public

PVSS manager usage: UI (PVSS00NV) and UI extended (PVSS00NG)

Constraints:
	. PVSS version: 3.0 
	. operating system: WXP.
	. distributed system: yes.
  
  @deprecated 2018-06-22
*/
unImportValidation_getTreeData(dyn_string dsFileContent, dyn_string &dsData, int &iIndex)
{
  FWDEPRECATED();

	unImportValidation_getTagSectionData(dsFileContent, dsData, iIndex, "<tree>", "<"+unTreeWidget_treeNodeDPT+">");
//  DebugN(iIndex, unTreeWidget_treeNodeDPT, dynlen(dsData));
}

